C**************************************************************************
C******    OEVING 2 2007                                            *******
C******    NUMERISK INTEGRASJON    ***** DELVIS LOESNINGSFORSLAG    *******
C**************************************************************************
C
C          NUMERISK INTEGRASJON AV FUNKSJONER VED BRUK AV 

C            1) TRAPESFORMELEN (METODE=TRA)
C            2) SIMPSONS METODE (METODE=SIM)
C
C  PARAMETRE
C     A = NEDRE INTEGRASJONSGRENSE
C     B = OEVRE INTEGRASJONSGRENSE
C     N = ANTALL INTERVALLER
C     H = INTERVALLENGDE
C
C  DEKLARASJONER
C
      REAL TRAPEZ,SIMPSO,FX1,FX2,FX3,FX4
      REAL ...
      INTEGER ...
      CHARACTER ...
      EXTERNAL FX1,FX2,FX3,FX4
C
C  AAPNE UTSKRIFTSFIL
C
      OPEN(....)
C
C  LES DATA FRA SKJERM
C
      SVAR="J"
      DO WHILE (SVAR.EQ."J")
      PRINT *," ..."
      READ(*,*) ...
      PRINT *," ANGI METODE (...)"
      READ(*,*) ...
      IF(METODE.EQ."TRA")THEN
      AREA1=...
      ...
      ...
      ...
      ...
      WRITE(12,200)A,B,N,AREA1,AREA2,AREA3,AREA4
  101 FORMAT(/," RESULTATER MED TRAPESMETODEN",/)
      ELSEIF(METODE.EQ."SIM")THEN
      AREA1=...
      ...
      ...
      ...
      ...
      WRITE(12,200)...
  200 FORMAT(" INNDATA:   A=",F6.2,"   B=",F6.2,"   N=",I3,/,  
     *       "   AREAL AV X**2         =", F10.6,/,  
     *       "   AREAL AV X**4         =", F10.6,/,
     *       "   AREAL AV 1/(1+X)      =", F10.6,/,
     *       "   AREAL AV SQRT(1+X**2) =", F10.6)
  102 FORMAT(/," ....",/)
      ENDIF
      PRINT *, " VIL DU GJOERE FLERE KJOERINGER? (J eller N)"
      READ(*,*)SVAR
      END DO
      CLOSE(12)
      END
C
C  TRAPESINTEGRASJON
C
      REAL FUNCTION TRAPEZ(A,B,N,FX)
      REAL ...
      INTEGER ...
      SUM=0.
      H=(B-A)/N
      X1=A
      DO 10 ...
      SUM=SUM+...
      X1=X1+H
   10 CONTINUE
      TRAPEZ=SUM
      RETURN
      END
C
C  SIMPSONSINTEGRASJON
C
      REAL FUNCTION SIMPSO(A,B,N,FX)
      REAL ...
      INTEGER ...
      SUM=0.
C
C     HUSK AT HER MAA N VAERE ET PARTALL
C
      IF(N/2*2.NE.N)THEN
      N=N+1
      WRITE(12,*)" N ER ENDRET TIL", N
      ENDIF
      ...
      ...
      DO 10 I=1,N,2
      SUM=SUM+...
      X1=X1+2.*H
   10 CONTINUE
      SIMPSO=SUM
      RETURN
      END
C
C  FUNKSJONER
C
      FUNCTION FX1(X)
      REAL ...
      FX1=X**2
      RETURN
      END
C
      FUNCTION FX2(X)
      ...
      ...
      ..
      END
C
      FUNCTION FX3(X)
      ...
      ...
      ..
      END
C
      REAL FUNCTION FX4(X)
      ...
      ...
      ..
      END
	  

